# ECMpy2.0
Automated construction of enzyme constraint models using ECMpy workflow.

## create environment

```shell
$ conda create -n ECMpy python=3.7  
$ conda activate ECMpy
```
## install package 

```shell
$ pip install cobra  
$ pip install openpyxl  
$ pip install requests  
$ pip install pebble  
$ pip install xlsxwriter  
$ pip install Bio   
$ pip install Require  
$ pip install quest   
$ pip install scikit-learn  
$ pip install RDKit  
$ pip install seaborn 
$ pip install pubchempy
$ pip install torch
$ pip install ipykernel 
$ python -m ipykernel install --user --name ECMpy --display-name "ECMpy"  
